@@ -17,12 +17,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-dashboard-extension.c,v 1.12 2004/09/26 16:07:58 chpe Exp $
+ *  $Id: ephy-dashboard-extension.c,v 1.17 2005/01/28 22:29:19 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-dashboard-extension.h"
 #include "dashboard-frontend-xmlwriter.h"
@@ -133,7 +131,7 @@ load_status_cb (EphyTab *tab,
 		{
 			char *content;
 
-			LOG ("Page is bookmarked, sending full content")
+			LOG ("Page is bookmarked, sending full content");
 
 			persist = EPHY_EMBED_PERSIST (ephy_embed_factory_new_object (EPHY_TYPE_EMBED_PERSIST));
 			ephy_embed_persist_set_embed (persist, embed);
@@ -142,9 +140,9 @@ load_status_cb (EphyTab *tab,
 			g_object_unref (persist);
 
 			DashboardSendCluePacket (
-				EPIPHANY_FRONTEND_IDENTIFIER,
+				(const xmlChar*) EPIPHANY_FRONTEND_IDENTIFIER,
 				ephy_tab_get_visibility(tab), /* focused */
-				location, /* context */
+				(const xmlChar*) location, /* context */
 				location, "url", 10,
 				page_title, "title", 10,
 				content, "htmlblock", 10,
@@ -154,12 +152,12 @@ load_status_cb (EphyTab *tab,
 		}
 		else
 		{
-			LOG ("Page not bookmarked, sending only location and title")
+			LOG ("Page not bookmarked, sending only location and title");
 
 			DashboardSendCluePacket (
-				EPIPHANY_FRONTEND_IDENTIFIER,
+				(const xmlChar*) EPIPHANY_FRONTEND_IDENTIFIER,
 				ephy_tab_get_visibility(tab), /* focused */
-				location, /* context */
+				(const xmlChar*) location, /* context */
 				location, "url", 10,
 				page_title, "title", 10,
 				NULL);
@@ -170,86 +168,36 @@ load_status_cb (EphyTab *tab,
 }
 
 static void
-tab_added_cb (GtkWidget *notebook,
-	      EphyTab *tab,
-	      EphyDashboardExtension *extension)
+impl_attach_tab (EphyExtension *extension,
+		 EphyWindow *window,
+		 EphyTab *tab)
 {
-	g_return_if_fail (EPHY_IS_TAB (tab));
-
 	g_signal_connect_after (tab, "notify::load-status",
 				G_CALLBACK (load_status_cb), extension);
 }
 
 static void
-tab_removed_cb (GtkWidget *notebook,
-		EphyTab *tab,
-		EphyDashboardExtension *extension)
+impl_detach_tab (EphyExtension *extension,
+		 EphyWindow *window,
+		 EphyTab *tab)
 {
-	g_return_if_fail (EPHY_IS_TAB (tab));
-
 	g_signal_handlers_disconnect_by_func
 		(tab, G_CALLBACK (load_status_cb), extension);
 }
 
-static void
-impl_attach_window (EphyExtension *ext,
-		    EphyWindow *window)
-{
-	EphyDashboardExtension *extension = EPHY_DASHBOARD_EXTENSION (ext);
-	GtkWidget *notebook;
-	GList *tabs, *l;
-
-	notebook = ephy_window_get_notebook (window);
-
-	g_signal_connect_after (notebook, "tab_added",
-				G_CALLBACK (tab_added_cb), ext);
-	g_signal_connect_after (notebook, "tab_removed",
-				G_CALLBACK (tab_removed_cb), ext);
-
-	tabs = ephy_window_get_tabs (window);
-	for (l = tabs; l != NULL; l = l->next)
-	{
-		tab_removed_cb (notebook, (EphyTab *) l->data, extension);
-	}
-	g_list_free (tabs);
-}
-
-static void
-impl_detach_window (EphyExtension *ext,
-		    EphyWindow *window)
-{
-	EphyDashboardExtension *extension = EPHY_DASHBOARD_EXTENSION (ext);
-	GtkWidget *notebook;
-	GList *tabs, *l;
-
-	notebook = ephy_window_get_notebook (window);
-
-	g_signal_handlers_disconnect_by_func
-		(notebook, G_CALLBACK (tab_added_cb), ext);
-	g_signal_handlers_disconnect_by_func
-		(notebook, G_CALLBACK (tab_removed_cb), ext);
-
-	tabs = ephy_window_get_tabs (window);
-	for (l = tabs; l != NULL; l = l->next)
-	{
-		tab_removed_cb (notebook, (EphyTab *) l->data, extension);
-	}
-	g_list_free (tabs);
-}
-
 static void
 ephy_dashboard_extension_init (EphyDashboardExtension *extension)
 {
 /*	extension->priv = EPHY_DASHBOARD_EXTENSION_GET_PRIVATE (extension);*/
 
-	LOG ("EphyDashboardExtension initialising")
+	LOG ("EphyDashboardExtension initialising");
 }
 
 static void
 ephy_dashboard_extension_iface_init (EphyExtensionIface *iface)
 {
-	iface->attach_window = impl_attach_window;
-	iface->detach_window = impl_detach_window;
+	iface->attach_tab = impl_attach_tab;
+	iface->detach_tab = impl_detach_tab;
 }
 
 static void
